@@ -5,9 +5,12 @@ class Node:
         Initialize List node. params:
         :data: data -> Any
         :next: frame or None
+        :value: selected value
         """
+        super().__init__()
         self.data = data
         self.next = None
+        #self.value = value
 
     def getData(self):
         return self.data
@@ -40,10 +43,10 @@ class OrderedList:
                     stop = True
                 else:
                     current = current.getNext()
-
         return found
 
     def procedure_push(self, item):
+        """Push value without hold in temporary object."""
         current = self.head
         previous = None
         stop = False
@@ -66,6 +69,9 @@ class OrderedList:
     def is_empty(self):
         return self.head == None
 
+    def is_full(self):
+        return self.head == self.head + 1
+
     def procedure_expand_size(self):
         """Expand value of list."""
         current = self.head
@@ -75,6 +81,14 @@ class OrderedList:
             current = current.getNext()
         return count
 
+    def procedure_delete_node(self):
+        """Function to delete node with specific value."""
+        node = Node()
+        if node is None or node.next is None:
+            raise ValueError
+        node.value = node.next.value
+        node.next = node.next.next
+
 class UnorderedList:
 
     def __init__(self):
@@ -83,6 +97,9 @@ class UnorderedList:
     def is_empty(self):
         return self.head == None
 
+    def is_full(self):
+        return self.head == self.head + 1
+
     def procedure_push(self, item):
         """Append a new object to list. Using 0(n)."""
         temporary = Node(item)
@@ -105,4 +122,11 @@ class UnorderedList:
                 found = True
             else:
                 current = current.getNext()
-        return found
\ No newline at end of file
+        return found
+
+    def procedure_delete_node(self):
+        node = Node()
+        if node is not None or node.next is None:
+            raise ValueError
+        node.value = node.next.value
+        node.next = node.next.next
\ No newline at end of file
